@@ -1,9 +1,14 @@
+//! Retrieve players.
 use crate::basketball_types::{ListReturnValue, Player};
 
+/// Query Params for players api request.
 pub struct PlayerQueryParams {
+    ///Page number for pagiantion.
     pub page: u32,
+    ///Number of values per page. Max 100.
     pub per_page: u32,
-    pub search: String,
+    ///Optional search string to search players
+    pub search: Option<String>,
 }
 
 impl Default for PlayerQueryParams {
@@ -11,21 +16,34 @@ impl Default for PlayerQueryParams {
         PlayerQueryParams {
             page: 0,
             per_page: 30,
-            search: "".to_string(),
+            search: None,
         }
     }
 }
 
+/// Get a vector of basketball players.
+///
+/// # Examples
+///
+/// ```
+/// get_players(Default::default())
+/// ```
 #[tokio::main]
 pub async fn get_players(
     query_params: PlayerQueryParams,
 ) -> Result<Vec<Player>, Box<dyn std::error::Error>> {
-    let query_params_list = vec![
+    let mut query_params_list = vec![
         ("page", query_params.page.to_string()),
-        ("per_page", query_params.per_page.to_string()),
-        ("search", query_params.search),
+        ("per_page", query_params.per_page.to_string())
     ];
 
+    if query_params.search.is_some() {
+        query_params_list.push((
+            "search",
+            query_params.search.unwrap().to_string(),
+        ))
+    }
+
     let client = reqwest::Client::new();
     let request_url = "https://www.balldontlie.io/api/v1/players";
     let resp = client
@@ -38,6 +56,13 @@ pub async fn get_players(
     Ok(resp.data)
 }
 
+/// Retrieves a basketball player.
+///
+/// # Examples
+///
+/// ```
+/// get_player(1)
+/// ```
 #[tokio::main]
 pub async fn get_player(player_id: u32) -> Result<Player, Box<dyn std::error::Error>> {
     let request_url = format!("https://www.balldontlie.io/api/v1/players/{}", player_id);
